@@ -1,7 +1,8 @@
-SUBMERCADOS = ["SUDESTE", "NORDESTE", "SUL", "NORTE"]
+SUBMERCADOS = ["SUDESTE", "SUL", "NORDESTE", "NORTE"]
 NUM_CENARIOS = 2000
 NUM_ANOS_ESTUDO = 5
 NUM_PATAMARES = 3
+NUM_VARIAVEIS_MEDIAS = 52
 MESES = ["JANEIRO",
          "FEVEREIRO",
          "MARCO",
